@@ -10,7 +10,7 @@ step in any mito analysis. It should transpile to nothing.
 """
 
 from collections import OrderedDict
-from mitosheet.utils import get_column_filter_type
+from mitosheet.sheet_functions.types.utils import get_mito_type
 
 INITIALIZE_DISPLAY_NAME = 'Created a Mitosheet'
 
@@ -38,7 +38,7 @@ def execute_initialize_step(wsc, dfs):
         # The column_metatype is if it stores formulas or values
         'column_metatype': [{key: 'value' for key in df.keys()} for df in dfs], 
         # The column_type is the type of the series in this column 
-        'column_type': [{key: get_column_filter_type(df[key]) for key in df.keys()} for df in dfs],
+        'column_type': [{key: get_mito_type(df[key]) for key in df.keys()} for df in dfs],
         # We make column_spreadsheet_code an ordered dictonary to preserve the order the formulas
         # are inserted, which in turn makes sure when we save + rerun an analysis, it's recreated
         # in the correct order (and thus the column order is preserved).
