@@ -144,3 +144,12 @@ def test_call_makes_copies():
 
     # Test we don't change the headers!
     assert df.columns.tolist() == ['A A']
+
+def test_can_call_with_indexes():
+    df = pd.DataFrame(data={'A': [1, 2, 3], 'B': ['A', 'B', 'C'], 'D': ['E', 'F', 'G']})
+
+    string_index = df.set_index('B')
+    sheet(string_index)
+
+    multi_index = df.set_index(['B', 'D'])
+    sheet(multi_index)
\ No newline at end of file
