@@ -9,6 +9,7 @@ Contains helpful utility functions
 """
 from copy import deepcopy
 import json
+from mitosheet.sheet_functions.types.utils import get_datetime_columns, get_mito_type, get_timedelta_columns
 import pandas as pd
 import numpy as np
 import numbers
@@ -121,15 +122,15 @@ def df_to_json_dumpsable(df: pd.DataFrame):
     # convert them to string columns (for formatting reasons).
     # NOTE: we don't use date_format='iso' in df.to_json call as it appends seconds to the object, 
     # see here: https://stackoverflow.com/questions/52730953/pandas-to-json-output-date-format-in-specific-form
-    date_columns = df.select_dtypes(include=['datetime64'])
-    for key in date_columns:
-        df[key] = date_columns[key].dt.strftime('%Y-%m-%d %X')
+    date_columns = get_datetime_columns(df)
+    for column_header in date_columns:
+        df[column_header] = df[column_header].dt.strftime('%Y-%m-%d %X')
 
     # Third, we figure out which of the columns contain timedeltas, and 
     # we format the timedeltas as strings to make them readable
-    date_diff_columns = df.select_dtypes(include=['timedelta64[ns]'])
-    for key in date_diff_columns:
-        df[key] = date_diff_columns[key].apply(lambda x: str(x))
+    timedelta_columns = get_timedelta_columns(df)
+    for column_header in timedelta_columns:
+        df[column_header] = df[column_header].apply(lambda x: str(x))
 
     json_obj = json.loads(df.to_json(orient="split"))
     # Then, we go through and find all the null values (which are infinities),
@@ -142,30 +143,6 @@ def df_to_json_dumpsable(df: pd.DataFrame):
     return json_obj
 
 
-def get_column_filter_type(series):
-    """
-    Given a series, take's the series dtype and catergorizes the correct
-    column_filter_type so that the filter modal can display only
-    valid filtering options
-    
-    TODO: unify this with the other Mito types!
-    """
-    try: 
-        if series.dtype == np.float64 or series.dtype == np.int64:
-            return 'number'
-        elif series.dtype == 'datetime64[ns]':
-            return 'datetime'
-        elif series.dtype == np.object:
-            return 'string'
-    except:
-        # If there is an error, we just call this a string column. In the wild, we have
-        # seen errors where dtype is not defined on the df object, but we have been
-        # unable to replicate this or figure out when it occurs.
-        return 'string'
-    
-    # TODO: what do we do if it's none? for now just return string, for no reason.
-    return 'string'
-
 def get_app_directory_from_jupyter_lab_path_output(output):
     """
     Takes the string output of `jupyter lab path` and returns the application folder for jupyter lab.
@@ -230,7 +207,7 @@ def add_df_to_step(step, new_df, df_name=None):
     # Update all the variables that depend on column_headers
     column_headers = new_df.keys()
     step['column_metatype'].append({column_header: 'value' for column_header in column_headers})
-    step['column_type'].append({column_header: get_column_filter_type(new_df[column_header]) for column_header in column_headers})
+    step['column_type'].append({column_header: get_mito_type(new_df[column_header]) for column_header in column_headers})
     step['column_spreadsheet_code'].append({column_header: '' for column_header in column_headers})
     step['column_python_code'].append({column_header: '' for column_header in column_headers})
     step['column_evaluation_graph'].append({column_header: set() for column_header in column_headers})
